/******************************************************************
  Template Name: Gutim
  Description: Gutim Fitness HTML Template
  Author: Colorlib
  Author URI: http://colorlib.com
  Version: 1.0
  Created: Colorlib
******************************************************************/

/*------------------------------------------------------------------
[Table of contents]

1.  Template default CSS
	1.1	Variables
	1.2	Mixins
	1.3	Flexbox
	1.4	Reset
2.  Helper Css
3.  Header Section
4.  Hero Section
5.  Services Section
6.  Class Section
7.  Trainer Section
8.  Membership Plan Section
9.  Contact
10.  Footer Style

-------------------------------------------------------------------*/

/*----------------------------------------*/

/* Template default CSS
/*----------------------------------------*/

html, body {
	height: 100%;
	font-family: "Poppins", sans-serif;
	-webkit-font-smoothing: antialiased;
	font-smoothing: antialiased;
}
h1, h2, h3, h4, h5, h6 {
	margin: 0;
	color: #111111;
	font-weight: 400;
	font-family: "Poppins", sans-serif;
}
h1 {
	font-size: 70px;
}
h2 {
	font-size: 36px;
}
h3 {
	font-size: 30px;
}
h4 {
	font-size: 24px;
}
h5 {
	font-size: 18px;
}
h6 {
	font-size: 16px;
}
p {
	font-size: 16px;
	font-family: "Poppins", sans-serif;
	color: #6b6b6b;
	font-weight: 400;
	line-height: 26px;
	margin: 0 0 15px 0;
}
img {
	max-width: 100%;
}
input:focus, select:focus, button:focus, textarea:focus {
	outline: none;
}
a:hover, a:focus {
	text-decoration: none;
	outline: none;
	color: #fff;
}
ul, ol {
	padding: 0;
	margin: 0;
}
/*---------------------
  Helper CSS
-----------------------*/

.section-title {
	text-align: center;
	margin-bottom: 45px;
}
.section-title h2 {
	color: #111111;
	font-size: 40px;
	font-weight: 600;
	text-transform: uppercase;
}
.set-bg {
	background-repeat: no-repeat;
	background-size: cover;
	background-position: top center;
}
.spad {
	padding-top: 100px;
	padding-bottom: 100px;
}
.spad-2 {
	padding-top: 50px;
	padding-bottom: 70px;
}
.text-white h1, .text-white h2, .text-white h3, .text-white h4, .text-white h5, .text-white h6, .text-white p, .text-white span, .text-white li, .text-white a {
	color: #fff;
}
/* buttons */

.primary-btn {
	display: inline-block;
	font-size: 16px;
	font-weight: 600;
	padding: 0 12px;
	color: #ffffff;
	text-align: center;
	width: 160px;
	height: 46px;
	border-left: 2px solid #eb3c5a;
	border-right: 2px solid #f67831;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	background-position: 0 0, 0 100%;
	background-repeat: no-repeat;
	background-size: 100% 2px;
	background-image: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831)), -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background-image: -o-linear-gradient(left, #eb3c5a 0%, #f67831 100%), -o-linear-gradient(left, #eb3c5a 0%, #f67831 100%);
	background-image: linear-gradient(to right, #eb3c5a 0%, #f67831 100%), linear-gradient(to right, #eb3c5a 0%, #f67831 100%);
	-webkit-transition-duration: 1000ms;
	-o-transition-duration: 1000ms;
	transition-duration: 1000ms;
	line-height: 45px;
	position: relative;
	z-index: 1;
}

.primary-btn:after {
	color: #fff;
	-webkit-transition-duration: 500ms;
	-o-transition-duration: 500ms;
	transition-duration: 500ms;
	background: #f67831;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	content: "";
	position: absolute;
	width: 100%;
	height: 100%;
	top: 0;
	left: 0;
	z-index: -1;
	opacity: 1;
}
/* Preloder */

#preloder {
	position: fixed;
	width: 100%;
	height: 100%;
	top: 0;
	left: 0;
	z-index: 999999;
	background: #000;
}
.loader {
	width: 40px;
	height: 40px;
	position: absolute;
	top: 50%;
	left: 50%;
	margin-top: -13px;
	margin-left: -13px;
	border-radius: 60px;
	animation: loader 0.8s linear infinite;
	-webkit-animation: loader 0.8s linear infinite;
}
@keyframes loader {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg);
		border: 4px solid #f44336;
		border-left-color: transparent;
	}
	50% {
		-webkit-transform: rotate(180deg);
		transform: rotate(180deg);
		border: 4px solid #673ab7;
		border-left-color: transparent;
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg);
		border: 4px solid #f44336;
		border-left-color: transparent;
	}
}
@-webkit-keyframes loader {
	0% {
		-webkit-transform: rotate(0deg);
		border: 4px solid #f44336;
		border-left-color: transparent;
	}
	50% {
		-webkit-transform: rotate(180deg);
		border: 4px solid #673ab7;
		border-left-color: transparent;
	}
	100% {
		-webkit-transform: rotate(360deg);
		border: 4px solid #f44336;
		border-left-color: transparent;
	}
}
/*---------------------
  Header
-----------------------*/

.header-section {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	border-bottom: 1px solid rgba(255, 255, 255, 0.2);
}
.logo {
	float: left;
}
.logo a {
	display: inline-block;
	padding: 24px 0 29px;
}
.nav-menu {
	float: right;
}
.nav-menu .mainmenu {
	display: inline-block;
}
.nav-menu .mainmenu ul li {
	list-style: none;
	display: inline-block;
	margin-right: 27px;
}
.nav-menu .mainmenu ul li.active a:after {
	opacity: 1;
}
.nav-menu .mainmenu ul li a {
	font-size: 16px;
	color: #ffffff;
	font-weight: 600;
	padding: 28px 0;
	position: relative;
}
.nav-menu .mainmenu ul li a:hover:after {
	opacity: 1;
}
.nav-menu .mainmenu ul li a:after {
	position: absolute;
	left: 0;
	bottom: 24px;
	width: 100%;
	height: 2px;
	background: #f15d44;
	content: "";
	opacity: 0;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.nav-menu .signup-btn {
	display: inline-block;
	margin: 16px 0px 16px 30px;
}
.nav-menu .signup-btn:after {
	opacity: 0;
}
.slicknav_menu {
	display: none;
}
/*---------------------
  Hero Section
-----------------------*/

.hero-section {
	height: 880px;
	padding-top: 335px;
}
.hero-text span {
	font-size: 14px;
	color: #f15d44;
	text-transform: uppercase;
	letter-spacing: 2px;
	font-weight: 600;
}
.hero-text h1 {
	font-size: 72px;
	color: #ffffff;
	font-weight: 600;
	margin-top: 11px;
	margin-bottom: 18px;
}
.hero-text p {
	color: #ffffff;
	margin-bottom: 44px;
}
/*---------------------
  About Section
-----------------------*/

.about-pic {
	position: relative;
}
.about-pic img {
	min-width: 100%;
}
.about-pic .play-btn {
	position: absolute;
	left: 50%;
	top: 50%;
	-webkit-transform: translate(-41.5px, -41.5px);
	-ms-transform: translate(-41.5px, -41.5px);
	transform: translate(-41.5px, -41.5px);
}
.about-text {
	padding-top: 15px;
	padding-left: 40px;
}
.about-text h2 {
	font-size: 40px;
	color: #111111;
	text-transform: uppercase;
	font-weight: 700;
	margin-bottom: 25px;
}
.about-text p {
	color: #6b6b6b;
}
.about-text p.first-para {
	margin-bottom: 10px;
}
.about-text p.second-para {
	margin-bottom: 50px;
}
.about-text img {
	margin-bottom: 25px;
}
.about-text .at-author h4 {
	font-size: 22px;
	color: #111111;
	font-weight: 600;
}
.about-text .at-author span {
	font-size: 12px;
	color: #f15d44;
}
.about-section.about-page .about-text {
	padding-top: 8px;
}
.about-section.about-page .about-text h2 {
	margin-bottom: 20px;
}
.about-section.about-page .about-text .second-para {
	margin-bottom: 28px;
}
/*---------------------
  Hero Section
-----------------------*/

.services-pic {
	margin-left: -15px;
	margin-right: -15px;
}
.services-pic img {
	height: 660px;
	min-width: 100%;
}
.services-item {
	margin-left: -15px;
	margin-right: -15px;
	background: #141414;
	padding-top: 130px;
	position: relative;
	padding-left: 70px;
	padding-right: 45px;
	height: 330px;
}
.services-item.bg-gray {
	background: #1e1e1e;
}
.services-item.pd-b {
	padding-top: 118px;
}
.services-item img {
	position: absolute;
	left: 70px;
	top: 80px;
}
.services-item h4 {
	font-size: 22px;
	color: #ffffff;
	font-weight: 600;
	margin-top: 36px;
	margin-bottom: 20px;
}
.services-item p {
	color: #bdbdbd;
	margin-bottom: 0;
}
/*---------------------
  Classes Section
-----------------------*/

.classes-section {
	padding-top: 90px;
	padding-bottom: 95px;
}
.classes-section.classes-page {
	padding-bottom: 60px;
}
.classes-slider {
	margin: 0;
}
.classes-slider .col-lg-4 {
	max-width: 100%;
}
.single-class-item {
	height: 255px;
	position: relative;
	margin-bottom: 30px;
}
.single-class-item .si-text {
	position: absolute;
	left: 0;
	bottom: 0;
	width: 100%;
	background: rgba(0, 0, 0, 0.4);
	padding-left: 30px;
	padding-top: 10px;
	padding-bottom: 15px;
}
.single-class-item .si-text h4 {
	font-size: 22px;
	font-weight: 600;
	color: #ffffff;
}
.single-class-item .si-text span {
	font-size: 14px;
	color: #ffffff;
}
.single-class-item .si-text span i {
	color: #e85d39;
	margin-right: 4px;
}
/*---------------------
  Trainer Section
-----------------------*/

.trainer-section {
	background: #f5f5f5;
	padding-top: 90px;
	padding-bottom: 190px;
}
.trainer-section.about-trainer {
	background: #ffffff;
}
.single-trainer-item {
	position: relative;
}
.single-trainer-item:hover .trainer-text {
	height: 250px;
	bottom: -90px;
	padding: 26px 30px 30px;
	-webkit-box-shadow: 0px 10px 49px 0px rgba(0, 0, 0, 0.15);
	box-shadow: 0px 10px 49px 0px rgba(0, 0, 0, 0.15);
}
.single-trainer-item:hover .trainer-text p {
	opacity: 1;
}
.single-trainer-item:hover .trainer-text .trainer-social {
	opacity: 1;
	visibility: visible;
}
.single-trainer-item img {
	min-width: 100%;
}
.single-trainer-item .trainer-text {
	position: absolute;
	left: 50%;
	bottom: -55px;
	text-align: center;
	background: #ffffff;
	width: 310px;
	margin: 0 auto;
	-webkit-transform: translateX(-155px);
	-ms-transform: translateX(-155px);
	transform: translateX(-155px);
	-webkit-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.15);
	box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.15);
	padding: 20px 30px 18px;
	height: 90px;
	-webkit-transition: all 0.5s;
	-o-transition: all 0.5s;
	transition: all 0.5s;
	overflow: hidden;
}
.single-trainer-item .trainer-text h5 {
	font-size: 20px;
	color: #111111;
	font-weight: 600;
	margin-bottom: 4px;
}
.single-trainer-item .trainer-text span {
	font-size: 16px;
	color: #f15d44;
}
.single-trainer-item .trainer-text p {
	margin-top: 7px;
	opacity: 0;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.single-trainer-item .trainer-text .trainer-social {
	opacity: 0;
	visibility: hidden;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.single-trainer-item .trainer-text .trainer-social a {
	display: inline-block;
	font-size: 17px;
	color: #111111;
	margin-right: 25px;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.single-trainer-item .trainer-text .trainer-social a:hover {
	color: #f15d44;
}
.single-trainer-item .trainer-text .trainer-social a:last-child {
	margin-right: 0;
}
/*---------------------
  Testimonial Section
-----------------------*/

.testimonial-section {
	position: relative;
}
.testimonial-section:after {
	position: absolute;
	left: 50%;
	top: 50%;
	width: 1100px;
	height: 540px;
	background: url(../meida/img/testimonial/testimonial-bg.png);
	content: "";
	-webkit-transform: translate(-550px, -270px);
	-ms-transform: translate(-550px, -270px);
	transform: translate(-550px, -270px);
}
.testimonial-section .section-title {
	margin-bottom: 35px;
}
.testimonial-slider .testimonial-item {
	text-align: center;
}
.testimonial-slider .testimonial-item p {
	font-size: 22px;
	color: #111111;
	line-height: 30px;
	margin-bottom: 60px;
}
.testimonial-slider .testimonial-item .ti-pic {
	width: 120px;
	height: 120px;
	margin: 0 auto;
	position: relative;
	z-index: 1;
}
.testimonial-slider .testimonial-item .ti-pic img {
	width: 120px;
	height: 120px;
	border-radius: 50%;
}
.testimonial-slider .testimonial-item .ti-pic .quote {
	position: absolute;
	left: 20px;
	top: -22px;
	z-index: -1;
}
.testimonial-slider .testimonial-item .ti-pic .quote img {
	width: auto;
	height: auto;
	border-radius: initial;
}
.testimonial-slider .testimonial-item .ti-author {
	margin-top: 25px;
}
.testimonial-slider .testimonial-item .ti-author h4 {
	font-size: 22px;
	color: #111111;
	font-weight: 600;
	margin-bottom: 8px;
}
.testimonial-slider .testimonial-item .ti-author span {
	font-size: 16px;
	color: #f15d44;
}
/*---------------------
  Banner Section
-----------------------*/

.banner-section {
	padding-top: 65px;
}
.banner-text {
	padding-top: 145px;
}
.banner-text h2 {
	font-size: 40px;
	color: #ffffff;
	font-weight: 600;
	text-transform: uppercase;
	margin-bottom: 20px;
}
.banner-text p {
	font-size: 18px;
	line-height: 30px;
	color: #ffffff;
	margin-bottom: 50px;
}
/*---------------------
  Membership Section
-----------------------*/

.membership-section {
	padding-bottom: 0;
}
.membership-section .section-title {
	margin-bottom: 55px;
}
.membership-item {
	text-align: center;
	background: #ffffff;
	-webkit-box-shadow: 0px 15px 49px rgba(0, 0, 0, 0.15);
	box-shadow: 0px 15px 49px rgba(0, 0, 0, 0.15);
	padding-bottom: 50px;
}
.membership-item .mi-title {
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	padding: 25px 0;
	position: relative;
	margin-bottom: 38px;
}
.membership-item .mi-title h4 {
	color: #ffffff;
	font-weight: 600;
	text-transform: uppercase;
}
.membership-item .mi-title:after {
	position: absolute;
	left: 50%;
	bottom: -14px;
	width: 30px;
	height: 15px;
	-webkit-transform: translateX(-15px);
	-ms-transform: translateX(-15px);
	transform: translateX(-15px);
	-webkit-clip-path: polygon(0% 0%, 50% 100%, 50% 100%, 100% 0%);
	clip-path: polygon(0% 0%, 50% 100%, 50% 100%, 100% 0%);
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	content: "";
}
.membership-item .mi-price {
	font-size: 40px;
	color: #f15d44;
	font-weight: 600;
	margin-bottom: 24px;
}
.membership-item .mi-price span {
	font-size: 16px;
	color: #6b6b6b;
	font-weight: 400;
}
.membership-item ul {
	margin-bottom: 27px;
}
.membership-item ul li {
	list-style: none;
	font-size: 16px;
	line-height: 36px;
}
.membership-item ul li p {
	margin-bottom: 0;
	color: #6b6b6b;
}
.membership-item ul li span {
	color: #111111;
	font-weight: 600;
}
.membership-item .membership-btn {
	color: #111111;
}
.membership-item .membership-btn:hover {
	color: #ffffff;
}
.membership-item .membership-btn:hover:after {
	opacity: 1;
}
.membership-item .membership-btn:after {
	opacity: 0;
}
/*---------------------
  Register Section
-----------------------*/

.register-section {
	background: #f5f4f4;
	padding-top: 235px;
	margin-top: -135px;
}
.register-section.classes-page {
	background: #ffffff;
	padding-top: 100px;
	margin-top: 0;
	padding-bottom: 0;
}
.register-section.classes-page .classes-page-text {
	-webkit-box-shadow: 0px 12px 21px rgba(0, 0, 0, 0.15);
	box-shadow: 0px 12px 21px rgba(0, 0, 0, 0.15);
}
.register-section .section-title {
	margin-bottom: 32px;
}
.register-section .section-title h2 {
	margin-bottom: 12px;
}
.register-text {
	padding: 50px 70px 60px 70px;
	background: #ffffff;
	margin-right: -15px;
}
.register-text .register-form label {
	font-size: 14px;
	color: #9b9b9b;
	margin-bottom: 11px;
}
.register-text .register-form input {
	width: 100%;
	height: 46px;
	border: 1px solid #ebebeb;
	padding-left: 20px;
	font-size: 14px;
	color: #9b9b9b;
	margin-bottom: 18px;
}
.register-text .register-form .register-btn {
	font-size: 16px;
	color: #ffffff;
	font-weight: 600;
	width: 100%;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	border: none;
	padding: 12px 0;
	cursor: pointer;
	margin-top: 30px;
}
.register-pic {
	margin-left: -15px;
}
.register-pic img {
	height: 502px;
}
/*---------------------
  Latest BLog Section
-----------------------*/

.latest-blog-section {
	padding-bottom: 50px;
}
.latest-blog-section .section-title {
	margin-bottom: 55px;
}
.latest-blog-section.recommend {
	padding-top: 0;
}
.latest-blog-section.recommend h3 {
	font-weight: 600;
	color: #111111;
	text-transform: uppercase;
	margin-bottom: 52px;
}
/*---------------------
  Footer Banner Section
-----------------------*/

.footer-banner-item {
	height: 400px;
	margin-left: -15px;
	margin-right: -15px;
	position: relative;
	padding-top: 85px;
	padding-left: 60px;
	padding-right: 60px;
	z-index: 1;
}
.footer-banner-item:after {
	position: absolute;
	left: 50%;
	top: 50%;
	width: 520px;
	height: 310px;
	border: 18px solid rgba(255, 255, 255, 0.1);
	content: "";
	-webkit-transform: translate(-260px, -155px);
	-ms-transform: translate(-260px, -155px);
	transform: translate(-260px, -155px);
	z-index: -1;
}
.footer-banner-item span {
	font-size: 16px;
	color: #f15d44;
	font-weight: 700;
	letter-spacing: 2px;
	text-transform: uppercase;
}
.footer-banner-item h2 {
	font-size: 40px;
	color: #ffffff;
	font-weight: 600;
	margin-top: 30px;
	margin-bottom: 5px;
}
.footer-banner-item p {
	color: #ffffff;
	margin-bottom: 42px;
}
/*---------------------
  Footer
-----------------------*/

.footer-section {
	background: #111111;
	padding-top: 60px;
	padding-bottom: 30px;
}
.contact-option span {
	font-size: 14px;
	color: #f15d44;
}
.contact-option p {
	font-size: 16px;
	color: #ffffff;
	margin-top: 15px;
}
.subscribe-option {
	overflow: hidden;
	padding: 0 45px;
	margin-bottom: 30px;
	margin-top: 43px;
}
.subscribe-option .so-text {
	float: left;
	padding: 34px 0 26px;
}
.subscribe-option .so-text h4 {
	color: #ffffff;
	font-weight: 600;
	text-transform: uppercase;
	margin-bottom: 6px;
}
.subscribe-option .so-text p {
	margin-bottom: 0;
	font-size: 14px;
	color: #ffffff;
}
.subscribe-option .subscribe-form {
	float: right;
	width: 340px;
	position: relative;
	margin: 37px 0;
}
.subscribe-option .subscribe-form input {
	width: 100%;
	height: 46px;
	font-size: 14px;
	color: #bdbdbd;
	border: 1px solid #ffffff;
	padding-left: 22px;
}
.subscribe-option .subscribe-form button {
	font-size: 18px;
	color: #ffffff;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	border: none;
	height: 46px;
	position: absolute;
	right: 0;
	top: 0;
	padding: 0 22px;
}
.copyright-text {
	overflow: hidden;
}
.copyright-text p {
	padding-top: 6px;
	float: left;
	color: #ffffff;
	margin-right: 25px;
	display: inline-block;
}
.copyright-text p a {
	color: #ffffff;
}
.copyright-text p a:hover {
	color: #eb3c5a;
}
.copyright-text ul {
	display: inline-block;
}
.copyright-text ul li {
	list-style: none;
	font-size: 16px;
	display: inline-block;
	margin-right: 25px;
	line-height: 40px;
}
.copyright-text ul li:last-child {
	margin-right: 0;
}
.copyright-text ul li a {
	color: #ffffff;
}
.copyright-text ul li:last-child {
	margin-right: 0;
}
.copyright-text .footer-social {
	float: right;
}
.copyright-text .footer-social a {
	display: inline-block;
	font-size: 16px;
	color: #ffffff;
	width: 40px;
	height: 40px;
	background: #282828;
	text-align: center;
	line-height: 40px;
	border-radius: 50%;
	margin-left: 4px;
}
.copyright-text .footer-social a:first-child {
	margin-left: 0;
}
.copyright-text .footer-social a:hover {
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
}
/*---------------------
  Breadcrumb Section
-----------------------*/

.breadcrumb-section {
	padding-top: 190px;
	height: 400px;
}
.breadcrumb-text {
	text-align: center;
}
.breadcrumb-text h2 {
	font-size: 60px;
	color: #ffffff;
	font-weight: 600;
	text-transform: uppercase;
	margin-bottom: 10px;
}
.breadcrumb-text .breadcrumb-option a {
	font-size: 16px;
	color: #ffffff;
	display: inline-block;
	margin-right: 10px;
	position: relative;
}
.breadcrumb-text .breadcrumb-option a:after {
	position: absolute;
	right: -10px;
	top: 0;
	content: "";
	font-family: "FontAwesome";
}
.breadcrumb-text .breadcrumb-option span {
	font-size: 16px;
	color: #bdbdbd;
	display: inline-block;
}
/*---------------------------
  Classes Timetable Section
----------------------------*/

.classes-timetable {
	padding-top: 0;
}
.classes-timetable .nav-controls {
	text-align: center;
	margin-bottom: 42px;
}
.classes-timetable .nav-controls ul li {
	list-style: none;
	font-size: 16px;
	color: #111111;
	font-weight: 600;
	display: inline-block;
	margin-right: 48px;
	text-transform: uppercase;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
	cursor: pointer;
}
.classes-timetable .nav-controls ul li.active {
	color: #f15d44;
}
.classes-timetable .nav-controls ul li:hover {
	color: #f15d44;
}
.classes-timetable .nav-controls ul li:last-child {
	margin-right: 0;
}
.schedule-table.filtering .ts-item {
	opacity: 0;
}
.schedule-table.filtering .ts-item.show {
	opacity: 1;
}
.schedule-table table {
	width: 100%;
	text-align: center;
	border: 1px solid #e1e1e1;
}
.schedule-table table thead tr th {
	font-size: 16px;
	color: #000000;
	font-weight: 600;
	text-transform: uppercase;
	padding: 25px 0;
	background: #f0f0f0;
}
.schedule-table table tbody tr {
	border-top: 1px solid #e5e5e5;
}
.schedule-table table tbody tr td {
	width: 146px;
	background: #ffffff;
	border-right: 1px solid #e5e5e5;
	padding: 18px 0;
	position: relative;
	z-index: 1;
}
.schedule-table table tbody tr td.ts-item {
	-webkit-transition: all 0.4s;
	-o-transition: all 0.4s;
	transition: all 0.4s;
}
.schedule-table table tbody tr td:after {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	content: "";
	opacity: 0;
	z-index: -1;
	-webkit-transition: all 0.5s;
	-o-transition: all 0.5s;
	transition: all 0.5s;
}
.schedule-table table tbody tr td.hover-bg:hover h6 {
	color: #ffffff;
}
.schedule-table table tbody tr td.hover-bg:hover span {
	color: #ffffff;
}
.schedule-table table tbody tr td.hover-bg:hover .trainer-name {
	color: #ffffff;
}
.schedule-table table tbody tr td.hover-bg:hover:after {
	opacity: 1;
}
.schedule-table table tbody tr td.workout-time {
	font-size: 16px;
	color: #000000;
	font-weight: 600;
	text-transform: uppercase;
}
.schedule-table table tbody tr td h6 {
	font-weight: 600;
	color: #f15d44;
	text-transform: uppercase;
	margin-bottom: 5px;
}
.schedule-table table tbody tr td span {
	font-size: 14px;
	font-weight: 600;
	color: #111111;
}
.schedule-table table tbody tr td .trainer-name {
	font-size: 14px;
	color: #6b6b6b;
}
/*---------------------
  About Counter
-----------------------*/

.about-counter-text {
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	overflow: hidden;
	padding: 35px 65px 15px;
}
.about-counter-text .single-counter {
	float: left;
	margin-right: 180px;
}
.about-counter-text .single-counter:last-child {
	margin-right: 0;
}
.about-counter-text .single-counter h1 {
	font-size: 72px;
	color: #ffffff;
	display: inline-block;
}
.about-counter-text .single-counter span {
	font-size: 72px;
	color: #ffffff;
	display: inline-block;
	line-height: 80px;
}
.about-counter-text .single-counter p {
	color: #ffffff;
	letter-spacing: 2px;
	text-transform: uppercase;
}
/*---------------------
  Gym Award Section
-----------------------*/

.award-text {
	padding-top: 20px;
}
.award-text h2 {
	font-size: 40px;
	font-weight: 600;
	color: #111111;
	text-transform: uppercase;
	margin-bottom: 20px;
}
.award-text p {
	margin-bottom: 10px;
}
/*---------------------
  Gallery Section
-----------------------*/

.gallery-section {
	padding-bottom: 70px;
}
.gallery-controls {
	text-align: center;
	margin-bottom: 55px;
}
.gallery-controls li {
	list-style: none;
	display: inline-block;
	font-size: 16px;
	font-weight: 600;
	color: #111111;
	text-transform: uppercase;
	margin-right: 30px;
	cursor: pointer;
}
.gallery-controls li.active {
	color: #f15d44;
}
.gallery-controls li:last-child {
	margin-right: 0;
}
.gallery-filter img {
	min-width: 100%;
	margin-bottom: 30px;
}
/*---------------------
  Blog Section
-----------------------*/

.blog-section {
	padding-bottom: 50px;
}
.single-blog-item {
	margin-bottom: 42px;
}
.single-blog-item img {
	min-width: 100%;
	margin-bottom: 30px;
}
.single-blog-item .blog-widget {
	margin-bottom: 10px;
}
.single-blog-item .blog-widget .bw-date {
	font-size: 14px;
	color: #bdbdbd;
	display: inline-block;
	margin-right: 8px;
}
.single-blog-item .blog-widget .tag {
	font-size: 14px;
	color: #f15d44;
}
.single-blog-item h4 a {
	color: #111111;
	font-weight: 600;
	line-height: 30px;
}
/*----------------------------
  Blog Details Hero Section
----------------------------*/

.blog-details {
	padding-top: 50px;
}
.blog-details-hero {
	height: 633px;
	padding-top: 280px;
}
.bd-hero-text {
	text-align: center;
}
.bd-hero-text span {
	font-size: 12px;
	color: #ffffff;
	text-transform: uppercase;
	background: #f15d44;
	letter-spacing: 2px;
	border-radius: 2px;
	padding: 4px 16px;
	display: inline-block;
}
.bd-hero-text h2 {
	color: #ffffff;
	font-size: 40px;
	font-weight: 600;
	line-height: 60px;
	text-transform: uppercase;
	margin-top: 15px;
}
.bd-text .bd-title {
	margin-bottom: 55px;
}
.bd-text .bd-title p {
	font-size: 17px;
	line-height: 30px;
}
.bd-text .bd-pic {
	margin-bottom: 35px;
}
.bd-text .bd-pic img {
	min-width: 100%;
	margin-bottom: 20px;
}
.bd-text .bd-more-text {
	margin-bottom: 52px;
}
.bd-text .bd-more-text .bm-item h4 {
	font-weight: 600;
	-webkit-column-rule: #111111;
	-moz-column-rule: #111111;
	column-rule: #111111;
	text-transform: uppercase;
	margin-bottom: 20px;
}
.bd-text .bd-more-text .bm-item p {
	font-size: 17px;
	line-height: 30px;
}
.bd-text .bd-quote {
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	padding: 40px 60px 30px 60px;
	position: relative;
	border-radius: 10px;
	z-index: 1;
	margin-bottom: 52px;
}
.bd-text .bd-quote samp {
	position: absolute;
	left: 45px;
	top: 35px;
	font-size: 89px;
	color: #ffffff;
	opacity: 0.1;
	line-height: 68px;
	z-index: -1;
}
.bd-text .bd-quote p {
	font-size: 24px;
	color: #ffffff;
	line-height: 36px;
	margin-bottom: 23px;
}
.bd-text .bd-quote .quote-author h5 {
	color: #ffffff;
	margin-bottom: 4px;
}
.bd-text .bd-quote .quote-author span {
	font-size: 14px;
	color: #ffffff;
}
.bd-text .bd-last-para {
	margin-bottom: 55px;
}
.bd-text .bd-last-para p {
	font-size: 17px;
	line-height: 30px;
}
.bd-text .tag-share {
	overflow: hidden;
	border-top: 1px solid #ebebeb;
	padding-top: 30px;
	margin-bottom: 60px;
}
.bd-text .tag-share .tags {
	float: left;
}
.bd-text .tag-share .tags a {
	font-size: 12px;
	color: #111111;
	text-transform: uppercase;
	background: #ebebeb;
	letter-spacing: 2px;
	border-radius: 2px;
	padding: 4px 16px;
	display: inline-block;
	font-weight: 500;
	margin-right: 6px;
	-webkit-transition: all 0.3s;
	-o-transition: all 0.3s;
	transition: all 0.3s;
}
.bd-text .tag-share .tags a:hover {
	color: #ffffff;
	background: #f15d44;
}
.bd-text .tag-share .tags a:last-child {
	margin-right: 0;
}
.bd-text .tag-share .social-share {
	float: right;
}
.bd-text .tag-share .social-share span {
	font-size: 18px;
	color: #111111;
	display: inline-block;
}
.bd-text .tag-share .social-share a {
	color: #111111;
	display: inline-block;
	font-size: 16px;
	margin-left: 25px;
}
.bd-text .blog-author {
	margin-bottom: 55px;
}
.bd-text .blog-author .ba-pic {
	background: #f7f7f7;
	padding: 28px 0;
	border-radius: 2px;
	text-align: center;
}
.bd-text .blog-author .ba-pic img {
	height: 144px;
	width: 144px;
	border-radius: 50%;
	border: 10px solid #ffffff;
}
.bd-text .blog-author .ba-text {
	padding-top: 35px;
}
.bd-text .blog-author .ba-text h5 {
	color: #111111;
	font-weight: 600;
	font-size: 20px;
	margin-bottom: 12px;
}
.bd-text .blog-author .ba-text p {
	font-size: 17px;
	margin-bottom: 30px;
}
.bd-text .blog-author .ba-text .bt-social a {
	display: inline-block;
	font-size: 14px;
	color: #111111;
	margin-right: 25px;
}
.bd-text .leave-comment h3 {
	color: #111111;
	font-weight: 600;
	margin-bottom: 32px;
}
.bd-text .leave-comment form input {
	width: 100%;
	height: 46px;
	border: 1px solid #ebebeb;
	padding-left: 20px;
	font-size: 16px;
	margin-bottom: 30px;
	color: #ebebeb;
}
.bd-text .leave-comment form input:focus {
	color: #111111;
}
.bd-text .leave-comment form textarea {
	width: 100%;
	height: 110px;
	border: 1px solid #ebebeb;
	padding-left: 20px;
	font-size: 16px;
	padding-top: 10px;
	color: #ebebeb;
	margin-bottom: 42px;
	resize: none;
}
.bd-text .leave-comment form textarea:focus {
	color: #111111;
}
.bd-text .leave-comment form button {
	font-size: 16px;
	color: #ffffff;
	padding: 10px 33px;
	display: inline-block;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	border: none;
}
/*---------------------
  Map Section
-----------------------*/

.map {
	height: 612px;
	position: relative;
}
.map iframe {
	width: 100%;
}
.map img {
	position: absolute;
	left: 50%;
	top: 50%;
	-webkit-transform: translate(-14px, -21px);
	-ms-transform: translate(-14px, -21px);
	transform: translate(-14px, -21px);
}
/*---------------------
  Contact Section
-----------------------*/

.contact-info h4 {
	font-weight: 600;
	color: #111111;
	text-transform: uppercase;
	margin-bottom: 47px;
}
.contact-info .contact-address .ca-widget {
	overflow: hidden;
	margin-bottom: 16px;
}
.contact-info .contact-address .ca-widget .cw-icon {
	height: 74px;
	width: 74px;
	border: 1px solid #ebebeb;
	border-radius: 50%;
	text-align: center;
	line-height: 74px;
	float: left;
	margin-right: 28px;
}
.contact-info .contact-address .ca-widget .cw-text {
	padding-top: 12px;
}
.contact-info .contact-address .ca-widget .cw-text h5 {
	color: #bdbdbd;
	margin-bottom: 5px;
}
.contact-info .contact-address .ca-widget .cw-text p {
	margin-bottom: 0;
	color: #111111;
	font-size: 18px;
}
.contact-form h4 {
	font-weight: 600;
	color: #111111;
	text-transform: uppercase;
	margin-bottom: 47px;
}
.contact-form form input {
	width: 100%;
	height: 51px;
	border: 1px solid #e1e1e1;
	padding-left: 20px;
	font-size: 16px;
	margin-bottom: 30px;
}
.contact-form form input::-webkit-input-placeholder {
	color: #9a9a9a;
}
.contact-form form input::-moz-placeholder {
	color: #9a9a9a;
}
.contact-form form input:-ms-input-placeholder {
	color: #9a9a9a;
}
.contact-form form input::-ms-input-placeholder {
	color: #9a9a9a;
}
.contact-form form input::placeholder {
	color: #9a9a9a;
}
.contact-form form input:focus {
	color: #111111;
}
.contact-form form textarea {
	width: 100%;
	height: 150px;
	border: 1px solid #e1e1e1;
	padding-left: 20px;
	font-size: 16px;
	padding-top: 10px;
	margin-bottom: 42px;
	resize: none;
}
.contact-form form textarea::-webkit-input-placeholder {
	color: #9a9a9a;
}
.contact-form form textarea::-moz-placeholder {
	color: #9a9a9a;
}
.contact-form form textarea:-ms-input-placeholder {
	color: #9a9a9a;
}
.contact-form form textarea::-ms-input-placeholder {
	color: #9a9a9a;
}
.contact-form form textarea::placeholder {
	color: #9a9a9a;
}
.contact-form form textarea:focus {
	color: #111111;
}
.contact-form form button {
	font-size: 14px;
	color: #ffffff;
	padding: 10px 33px;
	display: inline-block;
	background: -webkit-gradient(linear, left top, right top, from(#eb3c5a), to(#f67831));
	background: -o-linear-gradient(left, #eb3c5a, #f67831);
	background: linear-gradient(to right, #eb3c5a, #f67831);
	border: none;
	text-transform: uppercase;
}
/*-------------------------------- Respinsive Media Styles --------------------------------*/

@media only screen and (min-width: 1200px) {
	.container {
		max-width: 1170px;
	}
}
/* Medium Device: 1200px */

@media only screen and (min-width: 992px) and (max-width: 1199px) {
	.services-item {
		padding-top: 70px;
		padding-left: 37px;
		padding-right: 30px;
	}
	.services-item img {
		left: 40px;
		top: 35px;
	}
	.services-item.pd-b {
		padding-top: 70px;
	}
	.single-trainer-item .trainer-text {
		width: 282px;
		-webkit-transform: translateX(-141px);
		-ms-transform: translateX(-141px);
		transform: translateX(-141px);
	}
	.testimonial-section:after {
		width: 990px;
		-webkit-transform: translate(-495px, -270px);
		-ms-transform: translate(-495px, -270px);
		transform: translate(-495px, -270px);
	}
	.footer-banner-item:after {
		width: 450px;
		-webkit-transform: translate(-225px, -155px);
		-ms-transform: translate(-225px, -155px);
		transform: translate(-225px, -155px);
	}
	.about-counter-text .single-counter {
		margin-right: 110px;
	}
	.about-text {
		padding-top: 0;
		padding-left: 20px;
	}
	.award-text {
		padding-top: 0;
	}
	.bd-text .blog-author .ba-text {
		padding-top: 15px;
	}
}
@media only screen and (max-width: 991px) {
	.testimonial-section:after {
		display: none;
	}
	.banner-text {
		margin-bottom: 30px;
	}
	.single-trainer-item {
		margin-bottom: 110px;
	}
	.trainer-section {
		padding-bottom: 80px;
	}
	.membership-item {
		margin-bottom: 40px;
	}
	.register-section {
		padding-top: 195px;
	}
	.register-pic {
		margin-left: 0;
		padding-top: 30px;
	}
	.classes-page-text .register-pic {
		padding-top: 0;
	}
	.subscribe-option .so-text {
		float: none;
	}
	.subscribe-option .subscribe-form {
		float: none;
		margin: 5px 0 37px;
	}
	.award-text {
		margin-bottom: 30px;
	}
	.classes-page-text .register-pic img {
		min-width: 100%;
	}
	.contact-info {
		margin-bottom: 30px;
	}
	.register-text {
		margin-right: 0;
	}
}
/* Tablet Device: 768px */

@media only screen and (min-width: 768px) and (max-width: 991px) {
	.nav-menu .mainmenu ul li {
		margin-right: 12px;
	}
	.nav-menu .signup-btn {
		margin: 16px 0px 16px 0px;
		width: 145px;
	}
	.about-counter-text .single-counter {
		margin-right: 30px;
	}
	.services-pic img {
		height: auto;
	}
	.register-pic img {
		height: auto;
		min-width: 100%;
	}
}
/* Large Mobile: 480px */

@media only screen and (max-width: 767px) {
	.slicknav_menu {
		display: block;
		background: transparent;
		padding: 0;
		position: relative;
		z-index: 55;
	}
	.slicknav_btn {
		margin: 22px 0;
		border-radius: 0;
	}
	.slicknav_nav {
		background: #222;
	}
	.slicknav_nav ul {
		margin: 10px;
	}
	.slicknav_nav a:hover {
		border-radius: 0;
		background: #f15d44;
		color: #ffffff;
	}
	.slicknav_nav a {
		padding: 10px;
	}
	.nav-menu .mainmenu {
		display: none;
	}
	.nav-menu .signup-btn {
		display: none;
	}
	.hero-text h1 {
		font-size: 65px;
	}
	.services-pic img {
		height: auto;
	}
	.footer-banner-item:after {
		width: 450px;
		-webkit-transform: translate(-225px, -155px);
		-ms-transform: translate(-225px, -155px);
		transform: translate(-225px, -155px);
	}
	.banner-text {
		padding-top: 40px;
	}
	.register-pic img {
		height: auto;
		min-width: 100%;
	}
	.copyright-text {
		text-align: center;
	}
	.copyright-text p {
		float: none;
		display: block;
		margin-bottom: 20px;
		margin-right: 0;
	}
	.copyright-text .footer-social {
		float: none;
	}
	.about-section .about-text {
		padding-left: 0;
	}
	.about-counter-text {
		padding: 35px 35px 15px;
	}
	.about-counter-text .single-counter {
		float: none;
		margin-right: 0;
		text-align: center;
	}
	.schedule-table {
		overflow: auto;
	}
	.classes-timetable .nav-controls ul li {
		margin-right: 10px;
	}
	.gallery-controls li {
		margin-right: 15px;
	}
	.bd-text .tag-share .tags {
		float: none;
		margin-bottom: 10px;
	}
	.bd-text .tag-share .social-share {
		float: none;
	}
}
/* Small Mobile: 320px */

@media only screen and (max-width: 479px) {
	.hero-text h1 {
		font-size: 42px;
	}
	.single-trainer-item .trainer-text {
		width: 284px;
		-webkit-transform: translateX(-142px);
		-ms-transform: translateX(-142px);
		transform: translateX(-142px);
	}
	.footer-banner-item:after {
		width: 300px;
		-webkit-transform: translate(-150px, -155px);
		-ms-transform: translate(-150px, -155px);
		transform: translate(-150px, -155px);
	}
	.footer-banner-item {
		padding-top: 28px;
	}
	.subscribe-option {
		padding: 0 15px;
	}
	.subscribe-option .subscribe-form {
		width: 260px;
	}
	.copyright-text ul li {
		margin-right: 15px;
	}
	.register-text {
		padding: 50px 35px 60px 35px;
	}
	.services-item {
		padding-left: 40px;
		padding-top: 100px;
	}
	.services-item.pd-b {
		padding-top: 80px;
	}
	.services-item img {
		left: 40px;
		top: 40px;
	}
	.bd-text .tag-share .tags a {
		margin-bottom: 5px;
	}
	.gallery-controls li {
		margin-right: 10px;
	}
}