# Generated by Django 3.1.2 on 2020-10-13 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('activityLibrary', '0002_auto_20201013_1315'),
    ]

    operations = [
        migrations.AddField(
            model_name='recipe',
            name='ingredients',
            field=models.ManyToManyField(blank=True, to='activityLibrary.Ingredient'),
        ),
    ]
