# Generated by Django 3.1.2 on 2020-10-15 20:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0004_remove_profile_current_weight'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='carb_percent',
            field=models.DecimalField(decimal_places=1, default=55, help_text='Recommended Carbohydrate intake is between 45-65%', max_digits=3),
        ),
        migrations.AddField(
            model_name='profile',
            name='current_weight',
            field=models.IntegerField(default=0, help_text='Enter in lbs'),
        ),
        migrations.AddField(
            model_name='profile',
            name='fat_percent',
            field=models.DecimalField(decimal_places=1, default=25, help_text='Recommended fat intake is between 20-25%', max_digits=3),
        ),
        migrations.AddField(
            model_name='profile',
            name='protein_percent',
            field=models.DecimalField(decimal_places=1, default=20, help_text='Recommended Carbohydrate intake is between 80-100% of current body weight%', max_digits=3),
        ),
    ]
