# Generated by Django 3.1.2 on 2020-10-16 05:52

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0007_food'),
    ]

    operations = [
        migrations.AddField(
            model_name='food',
            name='date',
            field=models.DateField(default=django.utils.timezone.now),
        ),
    ]
