# Generated by Django 3.1.2 on 2020-10-15 04:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('activityLibrary', '0004_auto_20201014_1327'),
        ('activityLibrary', '0004_auto_20201013_2120'),
    ]

    operations = [
    ]
