# Generated by Django 3.1.2 on 2020-10-14 09:11

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('profile_picture', models.ImageField(default='default.jpg', upload_to='profile_pics')),
                ('daily_cal_in', models.IntegerField()),
                ('daily_carbs', models.IntegerField()),
                ('daily_fat', models.IntegerField()),
                ('daily_protein', models.IntegerField()),
                ('goal_weight_change', models.IntegerField()),
                ('activity_level', models.DecimalField(decimal_places=1, max_digits=2)),
                ('current_weight', models.IntegerField()),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
